## Configuration

[Full guide for reference](https://www.servicenow.com/docs/bundle/yokohama-platform-security/page/integrate/authentication/task/configure-api-key.html)

### Create an inbound authentication profile.

 1. Navigate to All > System Web Services > API Access Policies > Inbound Authentication Profiles.
 2. Select New.
 3. Select Create API Key authentication profiles
 4. Auth Parameter > add x-sn-apikey: Auth Header
 5. Submit the form.

### Create a REST API key

 1. Navigate to All > System Web Services > API Access Policies > REST API Key.
 2. Select New.
 3. Set name, description and user. Set expiry date if desired. > Submit.
 4. Open the record that was created to view the token generated by the ServiceNow AI Platform for the user.

### Create a REST API Access policy

 1. Navigate to All > System Web Services > REST API Access Policies.
 2. Select New.
 3. REST API = Table API
 4. Uncheck Apply to all tables > Select table > change_request
 5. in select profile from step 1 (API Key)


Use your `instance name` and `api_key` to set up Service Now configuration.
```yaml
toolsets:
  ServiceNow:
    enabled: true
    config:
      api_key: <api-token>
      instance: <dev1234..>
```
